@@ -44,7 +44,7 @@ PROJECTROLES_APP_SETTINGS = {
         'scope': 'PROJECT',
         'type': 'BOOLEAN',
         'default': False,
-        'label': 'IP Restrict',
+        'label': 'IP restrict',
         'description': 'Restrict project access by an allowed IP list',
         'user_modifiable': True,
         'local': False,
@@ -53,11 +53,22 @@ PROJECTROLES_APP_SETTINGS = {
         'scope': 'PROJECT',
         'type': 'JSON',
         'default': [],
-        'label': 'IP Allow List',
+        'label': 'IP allow list',
         'description': 'List of allowed IPs for project access',
         'user_modifiable': True,
         'local': False,
     },
+    'user_email_additional': {
+        'scope': 'USER',
+        'type': 'STRING',
+        'default': '',
+        'placeholder': 'email1@example.com;email2@example.com',
+        'label': 'Additional email',
+        'description': 'Also send user emails to these addresses. Separate '
+        'multiple emails with semicolon.',
+        'user_modifiable': True,
+        'local': False,
+    },
 }
 
 # Default setting for the ``local`` flag in app settings
@@ -179,31 +190,6 @@ class AppSettingAPI:
         except Exception:
             raise ValueError('Value is not valid JSON: {}'.format(value))
 
-    @classmethod
-    def _get_projectroles_settings(cls):
-        """
-        Return projectroles settings. If it exists, get value from
-        settings.PROJECTROLES_APP_SETTINGS_TEST for testing modifications.
-
-        :return: Dict
-        """
-        try:
-            app_settings = (
-                settings.PROJECTROLES_APP_SETTINGS_TEST
-                or PROJECTROLES_APP_SETTINGS
-            )
-        except AttributeError:
-            app_settings = PROJECTROLES_APP_SETTINGS
-
-        for k, v in app_settings.items():
-            if 'local' not in v:
-                raise ValueError(
-                    '"local" attribute is missing in projectroles app '
-                    'setting "{}"'.format(k)
-                )
-
-        return app_settings
-
     @classmethod
     def _compare_value(cls, setting_obj, input_value):
         """
@@ -233,7 +219,7 @@ class AppSettingAPI:
         :raise: KeyError if nothing is found with setting_name
         """
         if app_name == 'projectroles':
-            app_settings = cls._get_projectroles_settings()
+            app_settings = cls.get_projectroles_defs()
         else:
             app_plugin = get_app_plugin(app_name)
             if not app_plugin:
@@ -433,7 +419,7 @@ class AppSettingAPI:
 
         except AppSetting.DoesNotExist:
             if app_name == 'projectroles':
-                app_settings = cls._get_projectroles_settings()
+                app_settings = cls.get_projectroles_defs()
                 app_plugin_model = None
             else:
                 app_plugin = get_app_plugin(app_name)
@@ -579,7 +565,7 @@ class AppSettingAPI:
         if not plugin and not app_name:
             raise ValueError('Plugin and app name both unset')
         if app_name == 'projectroles':
-            app_settings = cls._get_projectroles_settings()
+            app_settings = cls.get_projectroles_defs()
         else:
             if not plugin:
                 plugin = get_app_plugin(app_name)
@@ -624,7 +610,7 @@ class AppSettingAPI:
         if not plugin and not app_name:
             raise ValueError('Plugin and app name both unset')
         if app_name == 'projectroles':
-            app_settings = cls._get_projectroles_settings()
+            app_settings = cls.get_projectroles_defs()
         else:
             if not plugin:
                 plugin = get_app_plugin(app_name)
@@ -656,3 +642,44 @@ class AppSettingAPI:
             cls._check_type(v['type'])
             cls._check_type_options(v['type'], v.get('options'))
         return setting_defs
+
+    @classmethod
+    def get_projectroles_defs(cls):
+        """
+        Return projectroles settings definitions. If it exists, get value from
+        settings.PROJECTROLES_APP_SETTINGS_TEST for testing modifications.
+
+        :return: Dict
+        """
+        try:
+            app_settings = (
+                settings.PROJECTROLES_APP_SETTINGS_TEST
+                or PROJECTROLES_APP_SETTINGS
+            )
+        except AttributeError:
+            app_settings = PROJECTROLES_APP_SETTINGS
+        for k, v in app_settings.items():
+            if 'local' not in v:
+                raise ValueError(
+                    'Attribute "local" is missing in projectroles app '
+                    'setting definition "{}"'.format(k)
+                )
+        return app_settings
+
+    @classmethod
+    def get_all_defs(cls):
+        """
+        Return app setting definitions for projectroles and all active app
+        plugins in a dictionary with the app name as key.
+
+        :return: Dict
+        """
+        ret = {'projectroles': cls.get_projectroles_defs()}
+        plugins = (
+            []
+            + get_active_plugins('project_app')
+            + get_active_plugins('site_app')
+        )
+        for p in plugins:
+            ret[p.name] = p.app_settings
+        return ret
