@@ -1,11 +1,12 @@
-import logging
-
 from django.contrib import auth
 from django.core.management.base import BaseCommand
 from django.db import transaction
 
+from projectroles.management.logging import ManagementCommandLogger
+
+
 User = auth.get_user_model()
-logger = logging.getLogger(__name__)
+logger = ManagementCommandLogger(__name__)
 
 
 class Command(BaseCommand):
@@ -16,19 +17,17 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         logger.info('Synchronizing user groups..')
-
         with transaction.atomic():
             for user in User.objects.all():
                 user.groups.clear()
                 user.save()  # Group is updated during save
 
                 if user.groups.count() > 0:
-                    logger.debug(
+                    logger.info(
                         'Group set: {} -> {}'.format(
                             user.username, user.groups.first().name
                         )
                     )
-
         logger.info(
             'Synchronized groups for {} users'.format(
                 User.objects.all().count()
