@@ -1,3 +1,5 @@
+"""Models for the projectroles app"""
+
 import logging
 import re
 import uuid
@@ -137,6 +139,13 @@ class Project(models.Model):
         help_text='Full project title with parent path (auto-generated)',
     )
 
+    #: Whether project has children with public access (auto-generated)
+    has_public_children = models.BooleanField(
+        default=False,
+        help_text='Whether project has children with public access '
+        '(auto-generated)',
+    )
+
     #: Project SODAR UUID
     sodar_uuid = models.UUIDField(
         default=uuid.uuid4, unique=True, help_text='Project SODAR UUID'
@@ -171,11 +180,16 @@ class Project(models.Model):
         for child in self.get_children():
             child.save()
 
+        # Update public children
+        # NOTE: Parents will be updated in ProjectModifyMixin.modify_project()
+        self.has_public_children = self._has_public_children()
+
         super().save(*args, **kwargs)
 
     def _validate_parent(self):
-        """Validate parent value to ensure project can't be set as its own
-        parent"""
+        """
+        Validate parent value to ensure project can't be set as its own parent.
+        """
         if self.parent == self:
             raise ValidationError('Project can not be set as its own parent')
 
@@ -190,8 +204,9 @@ class Project(models.Model):
             )
 
     def _validate_title(self):
-        """Validate title against parent title to ensure they don't equal
-        parent"""
+        """
+        Validate title against parent title to ensure they don't equal parent.
+        """
         if self.parent and self.title == self.parent.title:
             raise ValidationError('Project and parent titles can not be equal')
 
@@ -208,6 +223,33 @@ class Project(models.Model):
         ret += self.title
         return ret
 
+    def _has_public_children(self):
+        """
+        Return True if the project has any children with public guest access.
+        """
+        for child in self.get_children():
+            if child.public_guest_access:
+                return True
+            ret = child._has_public_children()
+            if ret:
+                return True
+        return False
+
+    def _update_public_children(self):
+        """Update has_public_children for this project's parents."""
+        if self.parent:
+            parent = self.parent
+            public_found = False
+            while parent:
+                if public_found:
+                    parent.has_public_children = True
+                else:
+                    parent.has_public_children = parent._has_public_children()
+                parent.save()
+                if not public_found and parent.has_public_children:
+                    public_found = True
+                parent = parent.parent
+
     # Custom row-level functions
 
     def get_children(self, flat=False):
@@ -232,16 +274,6 @@ class Project(models.Model):
             submit_status=SODAR_CONSTANTS['SUBMIT_STATUS_OK']
         ).order_by('title')
 
-    # TODO: Add tests
-    def has_public_children(self):
-        """
-        Return True if the project has any children with public guest access.
-        """
-        for child in self.get_children():
-            if child.public_guest_access:
-                return True
-            child.has_public_children()
-
     def get_depth(self):
         """Return depth of project in the project tree structure (root=0)"""
         ret = 0
@@ -256,12 +288,9 @@ class Project(models.Model):
         Return RoleAssignment for owner (without inherited owners) or None if
         not set.
         """
-        try:
-            return self.roles.get(
-                role__name=SODAR_CONSTANTS['PROJECT_ROLE_OWNER']
-            )
-        except RoleAssignment.DoesNotExist:
-            return None
+        return self.roles.filter(
+            role__name=SODAR_CONSTANTS['PROJECT_ROLE_OWNER']
+        ).first()
 
     def get_owners(self, inherited_only=False):
         """
@@ -272,19 +301,17 @@ class Project(models.Model):
         :return: List
         """
         owners = []
-        owner_as = self.get_owner()
-        if owner_as and not inherited_only:
-            owners.append(owner_as)
-        parent = self.parent
-
-        while parent:
-            parent_owner_as = parent.get_owner()
-            if parent_owner_as and parent_owner_as.user not in [
-                a.user for a in owners
-            ]:
-                owners.append(parent_owner_as)
-            parent = parent.parent
-
+        projects = list(self.get_parents())
+        if not inherited_only:
+            projects.append(self)
+        if projects:
+            db_owners = RoleAssignment.objects.filter(
+                role__name=SODAR_CONSTANTS['PROJECT_ROLE_OWNER'],
+                project__in=projects,
+            )
+            for parent_owner_as in db_owners:
+                if parent_owner_as.user not in [a.user for a in owners]:
+                    owners.append(parent_owner_as)
         return owners
 
     def is_owner(self, user):
@@ -353,7 +380,7 @@ class Project(models.Model):
         owners = self.get_owners() if inherited else [self.get_owner()]
         return owners + list(self.get_delegates()) + list(self.get_members())
 
-    def has_role(self, user, include_children=False):
+    def has_role(self, user, include_children=False, check_owner=True):
         """
         Return whether user has roles in Project. If include_children is
         True, return True if user has roles in ANY child project. Returns
@@ -362,14 +389,17 @@ class Project(models.Model):
         """
         if (
             self.public_guest_access
-            or self.is_owner(user)
             or self.roles.filter(user=user).count() > 0
+            or (check_owner and self.is_owner(user))
         ):
             return True
 
         if include_children:
             for child in self.children.all():
-                if child.has_role(user, include_children=True):
+                # Inherited ownership check is redundant for children
+                if child.has_role(
+                    user, include_children=True, check_owner=False
+                ):
                     return True
 
         return False
@@ -377,7 +407,7 @@ class Project(models.Model):
     def get_parents(self):
         """Return an array of parent projects in inheritance order"""
         if not self.parent:
-            return None
+            return []
         ret = []
         parent = self.parent
         while parent:
@@ -434,8 +464,10 @@ class Project(models.Model):
 
     def set_public(self, public=True):
         """Helper for setting value of public_guest_access"""
-        self.public_guest_access = public
-        self.save()
+        if public != self.public_guest_access:
+            self.public_guest_access = public
+            self.save()
+            self._update_public_children()  # Update for parents
 
 
 # Role -------------------------------------------------------------------------
@@ -1102,26 +1134,19 @@ class SODARUser(AbstractUser):
 
     def get_full_name(self):
         """Return full name or username if not set"""
-
         if hasattr(self, 'name') and self.name:
             return self.name
-
         elif self.first_name and self.last_name:
             return '{} {}'.format(self.first_name, self.last_name)
-
         return self.username
 
     def set_group(self):
         """Set user group based on user name."""
-
         if self.username.find('@') != -1:
             group_name = self.username.split('@')[1].lower()
-
         else:
             group_name = SODAR_CONSTANTS['SYSTEM_USER_GROUP']
-
         group, created = Group.objects.get_or_create(name=group_name)
-
         if group not in self.groups.all():
             group.user_set.add(self)
             return group_name
