@@ -20,9 +20,29 @@ SYSTEM_USER_GROUP = SODAR_CONSTANTS['SYSTEM_USER_GROUP']
 
 # Local constants
 CORE_SETTINGS = [
+    'ALLOWED_HOSTS',
+    'APPS_DIR',
+    'AUTH_LDAP_SERVER_URI',
+    'AUTH_LDAP2_SERVER_URI',
+    'DEBUG',
+    'EMAIL_BACKEND',
+    'EMAIL_HOST',
+    'EMAIL_PORT',
+    'EMAIL_SENDER',
+    'ENABLE_LDAP',
+    'ENABLE_SAML',
     'ENABLED_BACKEND_PLUGINS',
+    'ICONIFY_JSON_ROOT',
+    'INSTALLED_APPS',
+    'LANGUAGE_CODE',
+    'LOGGING_APPS',
+    'LOGGING_FILE_PATH',
+    'LOGGING_LEVEL',
+    'MANAGERS',
+    'MIDDLEWARE',
     'PROJECTROLES_ALLOW_ANONYMOUS',
     'PROJECTROLES_ALLOW_LOCAL_USERS',
+    'PROJECTROLES_BROWSER_WARNING',
     'PROJECTROLES_CUSTOM_JS_INCLUDES',
     'PROJECTROLES_CUSTOM_CSS_INCLUDES',
     'PROJECTROLES_DEFAULT_ADMIN',
@@ -30,6 +50,7 @@ CORE_SETTINGS = [
     'PROJECTROLES_DISABLE_CATEGORIES',
     'PROJECTROLES_DISABLE_CDN_INCLUDES',
     'PROJECTROLES_EMAIL_SENDER_REPLY',
+    'PROJECTROLES_ENABLE_PROFILING',
     'PROJECTROLES_ENABLE_SEARCH',
     'PROJECTROLES_HELP_HIGHLIGHT_DAYS',
     'PROJECTROLES_HIDE_APP_LINKS',
@@ -41,6 +62,8 @@ CORE_SETTINGS = [
     'PROJECTROLES_SEND_EMAIL',
     'PROJECTROLES_SITE_MODE',
     'PROJECTROLES_TARGET_CREATE',
+    'ROOT_DIR',
+    'SITE_PACKAGE',
     'SITE_TITLE',
     'SITE_SUBTITLE',
     'SITE_INSTANCE_TITLE',
@@ -48,6 +71,11 @@ CORE_SETTINGS = [
     'SODAR_API_DEFAULT_VERSION',
     'SODAR_API_DEFAULT_HOST',
     'SODAR_API_MEDIA_TYPE',
+    'STATICFILES_DIRS',
+    'STATICFILES_FINDERS',
+    'TEMPLATES',
+    'TIME_ZONE',
+    'USE_TZ',
 ]
 
 
